@@ -16,7 +16,7 @@ def fori(what_do_you_want_to_print_random_in_range_0_100):
 def wht():
     while True:
         True
-def cal(put_math_problem):
+def cal():
     while True:
-        z = eval(put_math_problem)
+        z = eval(input('Put your math problem here: '))
         print(z)
